==> craft_parts-1.19.8.tar.gz: craft_parts-1.19.8/tests/integration/plugins/test_ant.py <==
# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
#
# Copyright 2022 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License version 3 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import subprocess
import textwrap
from pathlib import Path

import yaml

from craft_parts import LifecycleManager, Step


def test_ant_plugin(new_dir, monkeypatch):
    monkeypatch.setenv("CRAFT_PARTS_PACKAGE_REFRESH", "0")
    source_location = Path(__file__).parent / "test_ant"

    parts_yaml = textwrap.dedent(
        f"""
        parts:
          foo:
            plugin: ant
            source: {source_location}
            stage-packages: [default-jre-headless]
            ant-build-targets: [compile, jar]
            ant-build-file: "my-build.xml"
            ant-properties:
              # The build will fail unless this property is propagated to Ant.
              EnableBuild: "yes"
        """
    )
    parts = yaml.safe_load(parts_yaml)
    lf = LifecycleManager(
        parts, application_name="test_ant", cache_dir=new_dir, work_dir=new_dir
    )
    actions = lf.plan(Step.PRIME)

    with lf.action_executor() as ctx:
        ctx.execute(actions)

    prime_dir = lf.project_info.prime_dir
    java_binary = Path(prime_dir, "bin", "java")
    assert java_binary.is_file()

    output = subprocess.check_output(
        [str(java_binary), "-jar", f"{prime_dir}/jar/HelloWorld.jar"], text=True
    )
    assert output.strip() == "Hello from Ant-built Java"

==> craft_parts-1.25.3.tar.gz: craft_parts-1.25.3/tests/integration/plugins/test_ant.py <==
# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
#
# Copyright 2022 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License version 3 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import subprocess
import textwrap
from pathlib import Path

import yaml

from craft_parts import LifecycleManager, Step


def test_ant_plugin(new_dir, partitions, monkeypatch):
    monkeypatch.setenv("CRAFT_PARTS_PACKAGE_REFRESH", "0")
    source_location = Path(__file__).parent / "test_ant"

    parts_yaml = textwrap.dedent(
        f"""
        parts:
          foo:
            plugin: ant
            source: {source_location}
            stage-packages: [default-jre-headless]
            ant-build-targets: [compile, jar]
            ant-build-file: "my-build.xml"
            ant-properties:
              # The build will fail unless this property is propagated to Ant.
              EnableBuild: "yes"
        """
    )
    parts = yaml.safe_load(parts_yaml)
    lf = LifecycleManager(
        parts,
        application_name="test_ant",
        cache_dir=new_dir,
        work_dir=new_dir,
        partitions=partitions,
    )
    actions = lf.plan(Step.PRIME)

    with lf.action_executor() as ctx:
        ctx.execute(actions)

    prime_dir = lf.project_info.prime_dir
    java_binary = Path(prime_dir, "bin", "java")
    assert java_binary.is_file()

    output = subprocess.check_output(
        [str(java_binary), "-jar", f"{prime_dir}/jar/HelloWorld.jar"], text=True
    )
    assert output.strip() == "Hello from Ant-built Java"
